@@ -5,9 +5,9 @@ package dstask
 import (
 	"errors"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"reflect"
+	"slices"
 	"sort"
 	"strings"
 	"time"
@@ -25,10 +25,10 @@ type SubTask struct {
 // to which it belongs.
 type Task struct {
 	// not stored in file -- rather filename and directory
-	UUID   string `json:"uuid" yaml:"-"` // TODO: use actual uuid.UUID type here
+	UUID   string `json:"uuid"   yaml:"-"` // TODO: use actual uuid.UUID type here
 	Status string `json:"status" yaml:",omitempty"`
 	// is new or has changed. Need to write to disk.
-	WritePending bool `json:"-" yaml:"-"`
+	WritePending bool `json:"-"      yaml:"-"`
 
 	// ephemeral, used to address tasks quickly. Non-resolved only. Populated
 	// from IDCache or on-the-fly.
@@ -62,41 +62,52 @@ type Task struct {
 }
 
 // Equals returns whether t2 equals task.
-// for equality, we only consider "core properties", we ignore WritePending, ID, Deleted and filtered
+// for equality, we only consider "core properties", we ignore WritePending, ID, Deleted and filtered.
 func (t Task) Equals(t2 Task) bool {
 	if t2.UUID != t.UUID {
 		return false
 	}
+
 	if t2.Status != t.Status {
 		return false
 	}
+
 	if t2.Summary != t.Summary {
 		return false
 	}
+
 	if t2.Notes != t.Notes {
 		return false
 	}
+
 	if !reflect.DeepEqual(t.Tags, t2.Tags) {
 		return false
 	}
+
 	if t2.Project != t.Project {
 		return false
 	}
+
 	if t2.Priority != t.Priority {
 		return false
 	}
+
 	if t2.DelegatedTo != t.DelegatedTo {
 		return false
 	}
+
 	if !reflect.DeepEqual(t.Subtasks, t2.Subtasks) {
 		return false
 	}
+
 	if !reflect.DeepEqual(t.Dependencies, t2.Dependencies) {
 		return false
 	}
+
 	if !t2.Created.Equal(t.Created) || !t2.Resolved.Equal(t.Resolved) || !t2.Due.Equal(t.Due) {
 		return false
 	}
+
 	return true
 }
 
@@ -118,16 +129,18 @@ func unmarshalTask(path string, finfo os.DirEntry, ids IdsMap, status string) (T
 		ID:     ids[uuid],
 	}
 
-	data, err := ioutil.ReadFile(path)
+	data, err := os.ReadFile(path)
 	if err != nil {
 		return Task{}, fmt.Errorf("failed to read %s", finfo.Name())
 	}
+
 	err = yaml.Unmarshal(data, &t)
 	if err != nil {
 		return Task{}, fmt.Errorf("failed to unmarshal %s", finfo.Name())
 	}
 
 	t.Status = status
+
 	return t, nil
 }
 
@@ -135,6 +148,7 @@ func (t Task) String() string {
 	if t.ID > 0 {
 		return fmt.Sprintf("%v: %s", t.ID, t.Summary)
 	}
+
 	return t.Summary
 }
 
@@ -164,11 +178,30 @@ func (t *Task) MatchesFilter(query Query) bool {
 		return false
 	}
 
+	if !query.Due.IsZero() {
+		if t.Due.IsZero() {
+			return false
+		}
+		if query.DateFilter == "after" && t.Due.Before(query.Due) {
+			return false
+		}
+		if query.DateFilter == "before" && t.Due.After(query.Due) {
+			return false
+		}
+		if (query.DateFilter == "on" || query.DateFilter == "in") && !t.Due.Equal(query.Due) {
+			return false
+		}
+		if query.DateFilter == "" && !t.Due.Equal(query.Due) {
+			return false
+		}
+	}
+
 	if query.Priority != "" && t.Priority != query.Priority {
 		return false
 	}
 
-	if query.Text != "" && !strings.Contains(strings.ToLower(t.Summary+t.Notes), strings.ToLower(query.Text)) {
+	if query.Text != "" &&
+		!strings.Contains(strings.ToLower(t.Summary+t.Notes), strings.ToLower(query.Text)) {
 		return false
 	}
 
@@ -224,7 +257,7 @@ func (t *Task) Validate() error {
 	return nil
 }
 
-// provides Summary + Last note if available
+// provides Summary + Last note if available.
 func (t *Task) LongSummary() string {
 	notes := strings.TrimSpace(t.Notes)
 	noteLines := strings.Split(notes, "\n")
@@ -233,6 +266,7 @@ func (t *Task) LongSummary() string {
 	if len(lastNote) > 0 {
 		return t.Summary + " " + NOTE_MODE_KEYWORD + " " + lastNote
 	}
+
 	return t.Summary
 }
 
@@ -246,7 +280,7 @@ func (t *Task) Modify(query Query) {
 	for i, tag := range t.Tags {
 		if StrSliceContains(query.AntiTags, tag) {
 			// delete item
-			t.Tags = append(t.Tags[:i], t.Tags[i+1:]...)
+			t.Tags = slices.Delete(t.Tags, i, i+1)
 		}
 	}
 
@@ -262,9 +296,14 @@ func (t *Task) Modify(query Query) {
 		t.Priority = query.Priority
 	}
 
+	if !query.Due.IsZero() {
+		t.Due = query.Due
+	}
+
 	if t.Notes != "" {
 		t.Notes += "\n"
 	}
+
 	t.Notes += query.Note
 }
 
@@ -279,7 +318,6 @@ func (t *Task) SaveToDisk(repoPath string) {
 		if err := os.Remove(filepath); err != nil {
 			ExitFail("Could not remove task %s: %v", filepath, err)
 		}
-
 	} else {
 		// Task is not deleted, and will be written to disk to a directory
 		// that indicates its current status. We make a shallow copy first,
@@ -287,13 +325,14 @@ func (t *Task) SaveToDisk(repoPath string) {
 		// to disk, with the Status field omitted. This avoids redundant data.
 		taskCp := *t
 		taskCp.Status = ""
+
 		d, err := yaml.Marshal(&taskCp)
 		if err != nil {
 			// TODO present error to user, specific error message is important
 			ExitFail("Failed to marshal task %s", t)
 		}
 
-		err = ioutil.WriteFile(filepath, d, 0600)
+		err = os.WriteFile(filepath, d, 0o600)
 		if err != nil {
 			ExitFail("Failed to write task %s", t)
 		}
@@ -315,3 +354,36 @@ func (t *Task) SaveToDisk(repoPath string) {
 		}
 	}
 }
+
+func (t *Task) ParseDueDateToStr() string {
+	due := t.Due
+	now := time.Now()
+	if due.IsZero() {
+		return ""
+	}
+	if due.YearDay() == now.YearDay() && t.Due.Year() == now.Year() {
+		return "today"
+	}
+	if due.YearDay() == now.AddDate(0, 0, 1).YearDay() && t.Due.Year() == now.AddDate(0, 0, 1).Year() {
+		return "tomorrow"
+	}
+	if due.YearDay() == now.AddDate(0, 0, -1).YearDay() && t.Due.Year() == now.AddDate(0, 0, -1).Year() {
+		return "yesterday"
+	}
+	return formatDueDate(due)
+}
+
+func formatDueDate(due time.Time) string {
+	now := time.Now()
+	year, _, _ := now.Date()
+	dueYear, _, _ := due.Date()
+
+	switch {
+	case due.After(now) && due.Sub(startOfDay(now)) < 7*24*time.Hour:
+		return due.Format("Mon _2")
+	case dueYear == year:
+		return due.Format("_2 Jan")
+	default:
+		return due.Format("_2 Jan 2006")
+	}
+}
