@@ -3,11 +3,12 @@ package dstask
 import (
 	"bufio"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"os/exec"
 	"runtime"
+	"slices"
 	"strings"
+	"time"
 	"unicode"
 	"unicode/utf8"
 
@@ -16,12 +17,12 @@ import (
 	"golang.org/x/sys/unix"
 )
 
-func ExitFail(format string, a ...interface{}) {
+func ExitFail(format string, a ...any) {
 	fmt.Fprintf(os.Stderr, "\033[31m"+format+"\033[0m\n", a...)
 	os.Exit(1)
 }
 
-func ConfirmOrAbort(format string, a ...interface{}) {
+func ConfirmOrAbort(format string, a ...any) {
 	fmt.Fprintf(os.Stderr, format+" [y/n] ", a...)
 
 	reader := bufio.NewReader(os.Stdin)
@@ -34,6 +35,7 @@ func ConfirmOrAbort(format string, a ...interface{}) {
 	if input == "y\n" {
 		return
 	}
+
 	ExitFail("Aborted.")
 }
 
@@ -49,6 +51,7 @@ func MustGetUUID4String() string {
 
 func IsValidUUID4String(str string) bool {
 	_, err := uuid.FromString(str)
+
 	return err == nil
 }
 
@@ -65,6 +68,35 @@ func IsValidStatus(status string) bool {
 	return StrSliceContains(ALL_STATUSES, status)
 }
 
+func ParseDueDateArg(dueStr string) (dateFilter string, dueDate time.Time) {
+	parts := strings.SplitN(dueStr, ":", 2)
+	if len(parts) != 2 {
+		ExitFail("Invalid due query format: " + dueStr + "\n" +
+			"Expected format: due:YYYY-MM-DD, due:MM-DD, due:DD, due:next-monday, due:today, etc.")
+	}
+	if parts[1] == "overdue" {
+		dateFilter = "before"
+		dueDate = startOfDay(time.Now())
+		return dateFilter, dueDate
+	}
+	tagParts := strings.SplitN(parts[0], ".", 2)
+	if len(tagParts) == 2 {
+		dateFilter = tagParts[1]
+
+		dateFilters := map[string]struct{}{"after": {}, "before": {}, "on": {}, "in": {}}
+		_, ok := dateFilters[dateFilter]
+		if !ok && dateFilter != "" {
+			ExitFail("Invalid date filter format: " + dateFilter + "\n" +
+				"Valid filters are: after, before, on, in")
+		}
+
+	} else {
+		dateFilter = ""
+	}
+	dueDate = ParseStrToDate(parts[1])
+	return dateFilter, dueDate
+}
+
 func SumInts(vals ...int) int {
 	var total int
 
@@ -80,6 +112,7 @@ func RunCmd(name string, args ...string) error {
 	cmd.Stdin = os.Stdin
 	cmd.Stdout = os.Stdout
 	cmd.Stderr = os.Stderr
+
 	return cmd.Run()
 }
 
@@ -88,8 +121,8 @@ func RunCmd(name string, args ...string) error {
 func MakeTempFilename(id int, summary, ext string) string {
 	truncated := make([]rune, utf8.RuneCountInString(summary))
 	i := 0
-	for _, r := range summary {
 
+	for _, r := range summary {
 		// If our utf8 grapheme cannot be encoded in a single byte, skip.
 		if utf8.RuneLen(r) != 1 {
 			continue // 👋
@@ -114,11 +147,14 @@ func MakeTempFilename(id int, summary, ext string) string {
 		}
 
 		truncated[i] = r
+
 		if i > 20 {
 			break
 		}
+
 		i++
 	}
+
 	truncated = truncated[:i]
 
 	loweredWithID := strings.ToLower(fmt.Sprintf("%v-%s", id, string(truncated)))
@@ -132,26 +168,33 @@ func MustEditBytes(data []byte, tmpFilename string) []byte {
 	if editor == "" {
 		editor = "vim"
 	}
-	tmpfile, err := ioutil.TempFile("", tmpFilename)
+
+	tmpfile, err := os.CreateTemp("", tmpFilename)
 	if err != nil {
 		ExitFail("Could not create temporary file to edit")
 	}
-	defer os.Remove(tmpfile.Name())
+
+	defer func() {
+		if err := os.Remove(tmpfile.Name()); err != nil {
+			fmt.Fprintf(os.Stderr, "Warning: failed to remove temporary file: %v\n", err)
+		}
+	}()
 
 	_, err = tmpfile.Write(data)
-	tmpfile.Close()
-
 	if err != nil {
 		ExitFail("Could not write to temporary file to edit")
 	}
 
+	if err := tmpfile.Close(); err != nil {
+		ExitFail("Could not close temporary file to edit")
+	}
+
 	err = RunCmd(editor, tmpfile.Name())
 	if err != nil {
 		ExitFail("Failed to run $EDITOR")
 	}
 
-	data, err = ioutil.ReadFile(tmpfile.Name())
-
+	data, err = os.ReadFile(tmpfile.Name())
 	if err != nil {
 		ExitFail("Could not read back temporary edited file")
 	}
@@ -160,39 +203,22 @@ func MustEditBytes(data []byte, tmpFilename string) []byte {
 }
 
 func StrSliceContains(haystack []string, needle string) bool {
-	for _, item := range haystack {
-		if item == needle {
-			return true
-		}
-	}
-
-	return false
+	return slices.Contains(haystack, needle)
 }
 
 // generics pls...
 func IntSliceContains(haystack []int, needle int) bool {
-	for _, item := range haystack {
-		if item == needle {
-			return true
-		}
-	}
-
-	return false
+	return slices.Contains(haystack, needle)
 }
 
 func StrSliceContainsAll(subset, superset []string) bool {
 	for _, have := range subset {
-		foundInSuperset := false
-		for _, want := range superset {
-			if have == want {
-				foundInSuperset = true
-				break
-			}
-		}
+		foundInSuperset := slices.Contains(superset, have)
 		if !foundInSuperset {
 			return false
 		}
 	}
+
 	return true
 }
 
@@ -228,14 +254,17 @@ func MustOpenBrowser(url string) {
 func DeduplicateStrings(s []string) []string {
 	seen := make(map[string]struct{}, len(s))
 	j := 0
+
 	for _, v := range s {
 		if _, ok := seen[v]; ok {
 			continue
 		}
+
 		seen[v] = struct{}{}
 		s[j] = v
 		j++
 	}
+
 	return s[:j]
 }
 
@@ -254,6 +283,7 @@ func MustGetTermSize() (int, int) {
 
 func StdoutIsTTY() bool {
 	isTTY := isatty.IsTerminal(os.Stdout.Fd()) || isatty.IsCygwinTerminal(os.Stdout.Fd())
+
 	return isTTY || FAKE_PTY
 }
 
@@ -261,5 +291,6 @@ func WriteStdout(data []byte) error {
 	if _, err := os.Stdout.Write(data); err != nil {
 		return err
 	}
+
 	return nil
 }
